@@ -51,6 +51,8 @@ class ShellTest(utils.TestCase):
             self.useFixture(fixtures.EnvironmentVariable(var,
                                                          self.FAKE_ENV[var]))
 
+        self.mock_completion()
+
         self.shell = shell.OpenStackCinderShell()
 
         self.requests = self.useFixture(requests_mock_fixture.Fixture())
@@ -94,13 +96,8 @@ class ShellTest(utils.TestCase):
         self.run_command('create --metadata key1="--test1" 1')
         self.assert_called('GET', '/volumes/1234')
         expected = {'volume': {'imageRef': None,
-                               'project_id': None,
-                               'status': 'creating',
                                'size': 1,
-                               'user_id': None,
                                'availability_zone': None,
-                               'source_replica': None,
-                               'attach_status': 'detached',
                                'source_volid': None,
                                'consistencygroup_id': None,
                                'name': None,
@@ -115,13 +112,8 @@ class ShellTest(utils.TestCase):
         self.run_command('create --metadata key1="--t1" --name="t" 1')
         self.assert_called('GET', '/volumes/1234')
         expected = {'volume': {'imageRef': None,
-                               'project_id': None,
-                               'status': 'creating',
                                'size': 1,
-                               'user_id': None,
                                'availability_zone': None,
-                               'source_replica': None,
-                               'attach_status': 'detached',
                                'source_volid': None,
                                'consistencygroup_id': None,
                                'name': '"t"',
@@ -135,13 +127,8 @@ class ShellTest(utils.TestCase):
     def test_delimit_metadata_args(self):
         self.run_command('create --metadata key1="test1" key2="test2" 1')
         expected = {'volume': {'imageRef': None,
-                               'project_id': None,
-                               'status': 'creating',
                                'size': 1,
-                               'user_id': None,
                                'availability_zone': None,
-                               'source_replica': None,
-                               'attach_status': 'detached',
                                'source_volid': None,
                                'consistencygroup_id': None,
                                'name': None,
@@ -157,13 +144,8 @@ class ShellTest(utils.TestCase):
         self.run_command('create --metadata key1="t1" --name="t" 1')
         self.assert_called('GET', '/volumes/1234')
         expected = {'volume': {'imageRef': None,
-                               'project_id': None,
-                               'status': 'creating',
                                'size': 1,
-                               'user_id': None,
                                'availability_zone': None,
-                               'source_replica': None,
-                               'attach_status': 'detached',
                                'source_volid': None,
                                'consistencygroup_id': None,
                                'name': '"t"',
@@ -345,19 +327,9 @@ class ShellTest(utils.TestCase):
         self.assert_called_anytime('POST', '/volumes', partial_body=expected)
         self.assert_called('GET', '/volumes/1234')
 
-    def test_create_volume_from_replica(self):
-        expected = {'volume': {'size': None}}
-
-        expected['volume']['source_replica'] = '1234'
-        self.run_command('create --source-replica=1234')
-        self.assert_called_anytime('POST', '/volumes', partial_body=expected)
-        self.assert_called('GET', '/volumes/1234')
-
     def test_create_volume_from_image(self):
-        expected = {'volume': {'status': 'creating',
-                               'size': 1,
-                               'imageRef': '1234',
-                               'attach_status': 'detached'}}
+        expected = {'volume': {'size': 1,
+                               'imageRef': '1234'}}
         self.run_command('create --image=1234 1')
         self.assert_called_anytime('POST', '/volumes', partial_body=expected)
         self.assert_called('GET', '/volumes/1234')
@@ -386,8 +358,7 @@ class ShellTest(utils.TestCase):
         self.assertRaises(SystemExit, self.run_command, 'create')
 
     def test_create_size_zero_if_not_snapshot_or_clone(self):
-        expected = {'volume': {'status': 'creating',
-                               'size': 0}}
+        expected = {'volume': {'size': 0}}
         self.run_command('create 0')
         self.assert_called_anytime('POST', '/volumes', partial_body=expected)
         self.assert_called('GET', '/volumes/1234')
@@ -560,10 +531,10 @@ class ShellTest(utils.TestCase):
     def test_rename_invalid_args(self):
         """Ensure that error generated does not reference an HTTP code."""
 
-        self.assertRaisesRegexp(exceptions.ClientException,
-                                '(?!HTTP)',
-                                self.run_command,
-                                'rename volume-1234-abcd')
+        self.assertRaisesRegex(exceptions.ClientException,
+                               '(?!HTTP)',
+                               self.run_command,
+                               'rename volume-1234-abcd')
 
     def test_rename_snapshot(self):
         # basic rename with positional arguments
@@ -1207,7 +1178,7 @@ class ShellTest(utils.TestCase):
 
     def test_list_transfer(self):
         self.run_command('transfer-list')
-        self.assert_called('GET', '/os-volume-transfer/detail')
+        self.assert_called('GET', '/os-volume-transfer/detail?all_tenants=0')
 
     def test_list_transfer_all_tenants(self):
         self.run_command('transfer-list --all-tenants=1')
