@@ -72,6 +72,19 @@ def do_type_list(cs, args):
     vtypes = cs.volume_types.list(search_opts=search_opts)
     shell_utils.print_volume_type_list(vtypes)
 
+    with cs.volume_types.completion_cache(
+            'uuid',
+            cinderclient.v3.volume_types.VolumeType,
+            mode="w"):
+        for vtype in vtypes:
+            cs.volume_types.write_to_completion_cache('uuid', vtype.id)
+    with cs.volume_types.completion_cache(
+            'name',
+            cinderclient.v3.volume_types.VolumeType,
+            mode="w"):
+        for vtype in vtypes:
+            cs.volume_types.write_to_completion_cache('name', vtype.name)
+
 
 @utils.arg('--all-tenants',
            metavar='<all_tenants>',
@@ -169,6 +182,9 @@ def do_backup_list(cs, args):
     shell_utils.translate_volume_snapshot_keys(backups)
     columns = ['ID', 'Volume ID', 'Status', 'Name', 'Size', 'Object Count',
                'Container']
+    if cs.api_version >= api_versions.APIVersion('3.56'):
+        columns.append('User ID')
+
     if args.sort:
         sortby_index = None
     else:
@@ -177,6 +193,20 @@ def do_backup_list(cs, args):
     if show_count:
         print("Backup in total: %s" % total_count)
 
+    with cs.backups.completion_cache(
+            'uuid',
+            cinderclient.v3.volume_backups.VolumeBackup,
+            mode="w"):
+        for backup in backups:
+            cs.backups.write_to_completion_cache('uuid', backup.id)
+    with cs.backups.completion_cache(
+            'name',
+            cinderclient.v3.volume_backups.VolumeBackup,
+            mode='w'):
+        for backup in backups:
+            if backup.name is not None:
+                cs.backups.write_to_completion_cache('name', backup.name)
+
 
 @utils.arg('--detail',
            action='store_true',
@@ -393,6 +423,20 @@ def do_list(cs, args):
         servers = [s.get('server_id') for s in vol.attachments]
         setattr(vol, 'attached_to', ','.join(map(str, servers)))
 
+    with cs.volumes.completion_cache('uuid',
+                                     cinderclient.v3.volumes.Volume,
+                                     mode="w"):
+        for vol in volumes:
+            cs.volumes.write_to_completion_cache('uuid', vol.id)
+
+    with cs.volumes.completion_cache('name',
+                                     cinderclient.v3.volumes.Volume,
+                                     mode="w"):
+        for vol in volumes:
+            if vol.name is None:
+                continue
+            cs.volumes.write_to_completion_cache('name', vol.name)
+
     if field_titles:
         # Remove duplicate fields
         key_list = ['ID']
@@ -481,7 +525,7 @@ def do_reset_state(cs, args):
            type=int,
            action=CheckSizeArgForCreate,
            help='Size of volume, in GiBs. (Required unless '
-                'snapshot-id/source-volid is specified).')
+                'snapshot-id/source-volid/backup-id is specified).')
 @utils.arg('--consisgroup-id',
            metavar='<consistencygroup-id>',
            default=None,
@@ -560,7 +604,9 @@ def do_reset_state(cs, args):
            dest='scheduler_hints',
            action='append',
            default=[],
-           help='Scheduler hint, like in nova.')
+           help='Scheduler hint, similar to nova. Repeat option to set '
+                'multiple hints. Values with the same key will be stored '
+                'as a list.')
 @utils.arg('--allow-multiattach',
            dest='multiattach',
            action="store_true",
@@ -640,6 +686,16 @@ def do_create(cs, args):
 
     utils.print_dict(info)
 
+    with cs.volumes.completion_cache('uuid',
+                                     cinderclient.v3.volumes.Volume,
+                                     mode="a"):
+        cs.volumes.write_to_completion_cache('uuid', volume.id)
+    if volume.name is not None:
+        with cs.volumes.completion_cache('name',
+                                         cinderclient.v3.volumes.Volume,
+                                         mode="a"):
+            cs.volumes.write_to_completion_cache('name', volume.name)
+
 
 @utils.arg('volume',
            metavar='<volume>',
@@ -908,19 +964,20 @@ def do_upload_to_image(cs, args):
     """Uploads volume to Image Service as an image."""
     volume = utils.find_volume(cs, args.volume)
     if cs.api_version >= api_versions.APIVersion("3.1"):
-        shell_utils.print_volume_image(
-            volume.upload_to_image(args.force,
-                                   args.image_name,
-                                   args.container_format,
-                                   args.disk_format,
-                                   args.visibility,
-                                   args.protected))
+        (resp, body) = volume.upload_to_image(args.force,
+                                              args.image_name,
+                                              args.container_format,
+                                              args.disk_format,
+                                              args.visibility,
+                                              args.protected)
+
+        shell_utils.print_volume_image((resp, body))
     else:
-        shell_utils.print_volume_image(
-            volume.upload_to_image(args.force,
-                                   args.image_name,
-                                   args.container_format,
-                                   args.disk_format))
+        (resp, body) = volume.upload_to_image(args.force,
+                                              args.image_name,
+                                              args.container_format,
+                                              args.disk_format)
+        shell_utils.print_volume_image((resp, body))
 
 
 @utils.arg('volume', metavar='<volume>', help='ID of volume to migrate.')
@@ -1271,7 +1328,7 @@ def do_manageable_list(cs, args):
            nargs='?',
            type=int,
            const=1,
-           default=utils.env('ALL_TENANTS', default=0),
+           default=utils.env('ALL_TENANTS', default=None),
            help='Shows details for all tenants. Admin only.')
 @utils.arg('--filters',
            type=six.text_type,
@@ -1546,7 +1603,7 @@ def do_group_list_replication_targets(cs, args):
            nargs='?',
            type=int,
            const=1,
-           default=0,
+           default=utils.env('ALL_TENANTS', default=None),
            help='Shows details for all tenants. Admin only.')
 @utils.arg('--status',
            metavar='<status>',
@@ -1570,10 +1627,8 @@ def do_group_list_replication_targets(cs, args):
 def do_group_snapshot_list(cs, args):
     """Lists all group snapshots."""
 
-    all_tenants = int(os.environ.get("ALL_TENANTS", args.all_tenants))
-
     search_opts = {
-        'all_tenants': all_tenants,
+        'all_tenants': args.all_tenants,
         'status': args.status,
         'group_id': args.group_id,
     }
@@ -2025,6 +2080,13 @@ def do_snapshot_list(cs, args):
     if show_count:
         print("Snapshot in total: %s" % total_count)
 
+    with cs.volume_snapshots.completion_cache(
+            'uuid',
+            cinderclient.v3.volume_snapshots.Snapshot,
+            mode='w'):
+        for snapshot in snapshots:
+            cs.volume_snapshots.write_to_completion_cache('uuid', snapshot.id)
+
 
 @api_versions.wraps('3.27')
 @utils.arg('--all-tenants',
@@ -2404,6 +2466,12 @@ def do_backup_create(cs, args):
 
     utils.print_dict(info)
 
+    with cs.backups.completion_cache(
+            'uuid',
+            cinderclient.v3.volume_backups.VolumeBackup,
+            mode="a"):
+        cs.backups.write_to_completion_cache('uuid', backup.id)
+
 
 @utils.arg('volume', metavar='<volume>',
            help='Name or ID of volume to transfer.')
